@@ -100,10 +100,7 @@ OnlineUser& NmdcHub::getUser(const string& aNick) {
 }
 
 void NmdcHub::supports(const StringList& feat) {
-    string x;
-    for(auto i = feat.begin(); i != feat.end(); ++i) {
-        x+= *i + ' ';
-    }
+    const string x = Util::toString(" ",feat);
     send("$Supports " + x + '|');
 }
 
@@ -1041,6 +1038,8 @@ void NmdcHub::on(Line, const string& aLine) noexcept {
     if (onClientMessage(this, validateMessage(aLine, true)))
         return;
 #endif
+    if (BOOLSETTING(NMDC_DEBUG))
+        fire(ClientListener::StatusMessage(), this, "<NMDC>" + aLine + "</NMDC>");
     Client::on(Line(), aLine);
     onLine(aLine);
 }
