@@ -1607,7 +1607,9 @@ void QueueManager::saveQueue(bool force) noexcept {
         string b32tmp;
         for(QueueItem::StringIter i = fileQueue.getQueue().begin(); i != fileQueue.getQueue().end(); ++i) {
             QueueItem* qi = i->second;
-            if(!qi->isSet(QueueItem::FLAG_USER_LIST)) {
+            if(!qi->isSet(QueueItem::FLAG_USER_LIST)
+                || (qi->isSet(QueueItem::FLAG_USER_LIST)
+                    && SETTING(KEEP_LISTS))) {
                 f.write(LIT("\t<Download Target=\""));
                 f.write(SimpleXML::escape(qi->getTarget(), tmp, true));
                 f.write(LIT("\" Size=\""));
@@ -2141,7 +2143,11 @@ void QueueManager::logFinishedDownload(QueueItem* qi, Download* d, bool crcError
     params["sfv"] = Util::toString(crcError ? 1 : 0);
 
     {
+#ifdef DO_NOT_USE_MUTEX
         FinishedManager::getInstance()->lockLists();
+#else // DO_NOT_USE_MUTEX
+        auto lock = FinishedManager::getInstance()->lockLists();
+#endif // DO_NOT_USE_MUTEX
         const FinishedManager::MapByFile& map = FinishedManager::getInstance()->getMapByFile(false);
         FinishedManager::MapByFile::const_iterator it = map.find(qi->getTarget());
         if(it != map.end()) {
@@ -2197,6 +2203,43 @@ void QueueManager::logFinishedDownload(QueueItem* qi, Download* d, bool crcError
     }
 
     LOG(LogManager::FINISHED_DOWNLOAD, params);
+#ifdef DO_NOT_USE_MUTEX
     FinishedManager::getInstance()->unlockLists();
+#endif // DO_NOT_USE_MUTEX
 }
+
+class ListMatcher : public dcpp::Thread
+{
+    public:
+        ListMatcher(const StringList& files_) : files(files_) { }
+        int run() {
+            for (auto i = files.cbegin(); i != files.cend(); ++i) {
+                UserPtr u = DirectoryListing::getUserFromFilename(*i);
+                if (!u)
+                    continue;
+
+                HintedUser user(u, Util::emptyString);
+                DirectoryListing dl(user);
+                try {
+                    dl.loadFile(*i);
+                    LogManager::getInstance()->message(str(F_("%1% : Matched %2% files") % Util::toString(ClientManager::getInstance()->getNicks(user)) % QueueManager::getInstance()->matchListing(dl)));
+                } catch (const Exception&) { }
+            }
+            delete this;// Cleanup the thread object
+            return 0;
+        }
+    private:
+        StringList files;
+};
+
+void QueueManager::matchAllListings() {
+    ListMatcher* matcher = new ListMatcher(File::findFiles(Util::getListPath(), "*.xml*"));
+    try {
+        matcher->start();
+    } catch (const ThreadException&) {
+        ///@todo add error message
+        delete matcher;
+    }
+}
+
 } // namespace dcpp
