@@ -595,20 +595,28 @@ bool SettingsManager::getType(const char* name, int& n, int& type) const {
 
 const std::string SettingsManager::parseCoreCmd(const std::string& cmd) {
     StringTokenizer<string> sl(cmd, ' ');
-        if (sl.getTokens().size() == 2) {
-            int n,type;
-            getType(sl.getTokens().at(0).c_str(),n,type);
-            if (type == SettingsManager::TYPE_INT) {
+    if (sl.getTokens().size() == 1 || sl.getTokens().size() == 2) {
+        int n,type; string tmp;
+        getType(sl.getTokens().at(0).c_str(),n,type);
+        if (type == SettingsManager::TYPE_INT) {
+            if (sl.getTokens().size() == 2) {
                 int i = atoi(sl.getTokens().at(1).c_str());
                 set((SettingsManager::IntSetting)n,i);
-            }
-            else if (type == SettingsManager::TYPE_STRING)
-                set((SettingsManager::StrSetting)n, sl.getTokens().at(1));
-            else
-                return _("Error: setting not found!");
-            return _("Change core setting ") + string(sl.getTokens().at(0)) + _(" to ") + string(sl.getTokens().at(1));
+            } else if (sl.getTokens().size() == 1)
+                tmp = Util::toString(get((SettingsManager::IntSetting)n,false));
         }
-    return _("Error: params have been not 2!");
+        else if (type == SettingsManager::TYPE_STRING) {
+            if (sl.getTokens().size() == 2)
+                set((SettingsManager::StrSetting)n, sl.getTokens().at(1));
+            else if (sl.getTokens().size() == 1)
+                tmp = get((SettingsManager::StrSetting)n,false);
+         } else
+            return _("Error: setting not found!");
+        return !tmp.empty() ?
+        _("Core setting ") + string(sl.getTokens().at(0)) + ": " + tmp :
+        _("Change core setting ") + string(sl.getTokens().at(0)) + _(" to ") + string(sl.getTokens().at(1));
+    }
+    return _("Error: segv parser :D");
 }
 
 } // namespace dcpp
