@@ -39,7 +39,7 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 #include <sys/utsname.h>
-#include <ctype.h>
+#include <cctype>
 #endif
 #ifdef HAVE_IFADDRS_H
 #include <ifaddrs.h>
@@ -203,7 +203,7 @@ void Util::initialize(PathsMap pathOverrides) {
     if(localMode) {
         // @todo implement...
     }
-    
+
     if (Util::getPath(Util::PATH_USER_LOCAL).empty()) {
 #ifdef FORCE_XDG
         const char *xdg_data_home_ = getenv("XDG_DATA_HOME");
@@ -215,7 +215,7 @@ void Util::initialize(PathsMap pathOverrides) {
         paths[PATH_USER_LOCAL] = paths[PATH_USER_CONFIG];
 #endif
     }
-    
+
     if (Util::getPath(Util::PATH_RESOURCES).empty())
         paths[PATH_RESOURCES] = paths[PATH_USER_CONFIG];
     if (Util::getPath(Util::PATH_LOCALE).empty())
@@ -376,7 +376,7 @@ static const char badChars[] = {
  * Replaces all strange characters in a file with '_'
  * @todo Check for invalid names such as nul and aux...
  */
-string Util::validateFileName(string tmp) {
+string Util::validateFileName(string tmp, const string& badCharsExtra) {
     string::size_type i = 0;
 
     // First, eliminate forbidden chars
@@ -385,6 +385,14 @@ string Util::validateFileName(string tmp) {
         i++;
     }
 
+        i = 0;
+        if(!badCharsExtra.empty()) {
+            while( (i = tmp.find_first_of(badCharsExtra.c_str(), i)) != string::npos) {
+            tmp[i] = '_';
+            i++;
+        }
+        }
+
     // Then, eliminate all ':' that are not the second letter ("c:\...")
     i = 0;
     while( (i = tmp.find(':', i)) != string::npos) {
@@ -503,16 +511,17 @@ void Util::decodeUrl(const string& url, string& protocol, string& host, uint16_t
             fragmentStart++;
     }
 
-    size_t queryStart = url.rfind('?', queryEnd);
-    size_t fileEnd;
-
+    //size_t queryStart = url.rfind('?', queryEnd);
+    //size_t fileEnd;
     //if(queryStart == string::npos) {
-            fileEnd = queryStart = queryEnd;
+            //fileEnd = queryStart = queryEnd;
     //} else {
             //dcdebug("q");
             //fileEnd = queryStart;
             //queryStart++;
     //}
+    size_t queryStart = queryEnd;
+    size_t fileEnd = queryStart;
 
     size_t protoStart = 0;
     size_t protoEnd = url.find("://", protoStart);
@@ -743,11 +752,11 @@ string Util::getLocalIp() {
     // We take the first ip as default, but if we can find a better one, use it instead...
     memcpy(&(dest.sin_addr), he->h_addr_list[i++], he->h_length);
     tmp = inet_ntoa(dest.sin_addr);
-    if(Util::isPrivateIp(tmp) || strncmp(tmp.c_str(), "169", 3) == 0) {
+    if(Util::isPrivateIp(tmp) || ::strncmp(tmp.c_str(), "169", 3) == 0) {
         while(he->h_addr_list[i]) {
             memcpy(&(dest.sin_addr), he->h_addr_list[i], he->h_length);
             string tmp2 = inet_ntoa(dest.sin_addr);
-            if(!Util::isPrivateIp(tmp2) && strncmp(tmp2.c_str(), "169", 3) != 0) {
+            if(!Util::isPrivateIp(tmp2) && ::strncmp(tmp2.c_str(), "169", 3) != 0) {
                 tmp = tmp2;
             }
             i++;
