@@ -21,6 +21,8 @@ using namespace std;
 
 // ./cli-jsonrpc-curl.pl  '{"jsonrpc": "2.0", "id": "1", "method": "show.version"}'
 // ./cli-jsonrpc-curl.pl '{"jsonrpc": "2.0", "id": "sv0t7t2r", "method": "queue.getsources", "params":{"target": "/home/egik/Видео/Shakugan no Shana III - 16 - To Battle, Once More [Zero-Raws].mp4"}}'
+// ./cli-jsonrpc-curl.pl '{"jsonrpc": "2.0", "id": "sv0t7t2r", "method": "hub.add", "params":{"huburl": "adc://localhost:1511"}}'
+// ./cli-jsonrpc-curl.pl '{"jsonrpc": "2.0", "id": "1", "method": "hub.pm", "params":{"huburl": "adc://localhost:1511", "nick" : "test", "message" : "test"}}'
 
 bool JsonRpcMethods::StopDaemon(const Json::Value& root, Json::Value& response)
 {
@@ -56,7 +58,7 @@ bool JsonRpcMethods::HubAdd(const Json::Value& root, Json::Value& response)
     response["jsonrpc"] = "2.0";
     response["id"] = root["id"];
     ServerThread::getInstance()->connectClient(root["params"]["huburl"].asString(), root["params"]["enc"].asString());
-    response["result"] = "Connecting to " + root["huburl"].asString();
+    response["result"] = "Connecting to " + root["params"]["huburl"].asString();
     if (isDebug) std::cout << "HubAdd (response): " << response << std::endl;
     return true;
 }
@@ -90,8 +92,10 @@ bool JsonRpcMethods::HubSayPM(const Json::Value& root, Json::Value& response)
     if (isDebug) std::cout << "HubSayPM (root): " << root << std::endl;
     response["jsonrpc"] = "2.0";
     response["id"] = root["id"];
-    string tmp = ServerThread::getInstance()->sendPrivateMessage(root["params"]["huburl"].asString(), root["params"]["nick"].asString(), root["params"]["message"].asString());
-    response["result"] = tmp;
+    if (ServerThread::getInstance()->sendPrivateMessage(root["params"]["huburl"].asString(), root["params"]["nick"].asString(), root["params"]["message"].asString()))
+        response["result"] = 0;
+    else
+        response["result"] = 1;
     if (isDebug) std::cout << "HubSayPM (response): " << response << std::endl;
     return true;
 }
@@ -266,9 +270,9 @@ bool JsonRpcMethods::ShowRatio(const Json::Value& root, Json::Value& response)
         ratio = 0;
     string upload = Util::formatBytes(up);
     string download = Util::formatBytes(down);
-    response["ratio"] = Util::toString(ratio);
-    response["up"] = upload;
-    response["down"] = download;
+    response["result"]["ratio"] = Util::toString(ratio);
+    response["result"]["up"] = upload;
+    response["result"]["down"] = download;
     if (isDebug) std::cout << "ShowRatio (response): " << response << std::endl;
     return true;
 }
@@ -353,7 +357,7 @@ bool JsonRpcMethods::AddQueueItem(const Json::Value& root, Json::Value& response
     if (isDebug) std::cout << "AddQueueItem (root): " << root << std::endl;
     response["jsonrpc"] = "2.0";
     response["id"] = root["id"];
-    
+
     if (isDebug) std::cout << "AddQueueItem (response): " << response << std::endl;
     return true;
 }
@@ -407,389 +411,57 @@ bool JsonRpcMethods::PauseHash(const Json::Value& root, Json::Value& response) {
     if (isDebug) std::cout << "PauseHash (response): " << response << std::endl;
     return true;
 }
-Json::Value JsonRpcMethods::GetDescriptionStopDaemon() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value returns;
 
-  root["description"] = "Stop daemon";
-  root["parameters"] = Json::Value::null;
-  returns["type"] = "integer";
-  returns["description"] = "Return 0 on success and 1 on failed";
-  root["returns"] = returns;
-
-  return root;
+bool JsonRpcMethods::MatchAllLists(const Json::Value& root, Json::Value& response) {
+    if (isDebug) std::cout << "MatchAllLists (root): " << root << std::endl;
+    response["jsonrpc"] = "2.0";
+    response["id"] = root["id"];
+    ServerThread::getInstance()->matchAllList();
+        response["result"] = 0;
+    if (isDebug) std::cout << "MatchAllLists (response): " << response << std::endl;
+    return true;
 }
 
-Json::Value JsonRpcMethods::GetDescriptionMagnetAdd() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-
-  root["description"] = "Add magnet in queue";
-  param1["type"] = "string";
-  param1["description"] = "Magnet link";
-  param2["type"] = "string";
-  param2["description"] = "Download directory";
-
-  parameters["magnet"] = param1;
-  parameters["directory"] = param2;
-  root["parameters"] = parameters;
-
-  returns["type"] = "integer";
-  returns["description"] = "Return 0 on success and 1 on failed";
-  root["returns"] = returns;
-
-  return root;
+bool JsonRpcMethods::ListHubsFullDesc(const Json::Value& root, Json::Value& response)
+{
+    if (isDebug) std::cout << "ListHubsFullDesc (root): " << root << std::endl;
+    response["jsonrpc"] = "2.0";
+    response["id"] = root["id"];
+    Json::Value parameters;
+    unordered_map<string,StringMap> listhubs;
+    ServerThread::getInstance()->listHubsFullDesc(listhubs);
+    for (auto i = listhubs.begin(); i != listhubs.end(); ++i) {
+        for (auto kk = i->second.begin(); kk != i->second.end(); ++kk) {
+            parameters[i->first][kk->first] = kk->second;
+        }
+    }
+    response["result"] = parameters;
+    if (isDebug) std::cout << "ListHubsFullDesc (response): " << response << std::endl;
+    return true;
 }
 
-Json::Value JsonRpcMethods::GetDescriptionHubAdd() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-
-  root["description"] = "Connect to huburl";
-  param1["type"] = "string";
-  param1["description"] = "Hub url";
-  param2["type"] = "string";
-  param2["description"] = "Encoding";
-
-  parameters["huburl"] = param1;
-  parameters["enc"] = param2;
-  root["parameters"] = parameters;
-
-  returns["type"] = "integer";
-  returns["description"] = "Return 0 on success and 1 on failed";
-  root["returns"] = returns;
-
-  return root;
+bool JsonRpcMethods::GetHubUserList(const Json::Value& root, Json::Value& response) {
+    if (isDebug) std::cout << "GetHubUserList (root): " << root << std::endl;
+    response["jsonrpc"] = "2.0";
+    response["id"] = root["id"];
+    string tmp; Json::Value parameters;
+    ServerThread::getInstance()->getHubUserList(tmp, root["params"]["huburl"].asString(), root["params"]["separator"].asString());
+    response["result"] = tmp;
+    if (isDebug) std::cout << "GetHubUserList (response): " << response << std::endl;
+    return true;
 }
 
-Json::Value JsonRpcMethods::GetDescriptionHubDel() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1;
-  Json::Value returns;
-  root["description"] = "Disconnect from huburl";
-  param1["type"] = "string";
-  param1["description"] = "Hub url";
-  
-  parameters["huburl"] = param1;
-  root["parameters"] = parameters;
-
-  returns["type"] = "integer";
-  returns["description"] = "Return 0 on success and 1 on failed";
-  root["returns"] = returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionHubSay() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  
-  root["description"] = "Send message on hub url";
-  param1["type"] = "string";
-  param1["description"] = "Hub url";
-  param2["type"] = "string";
-  param2["description"] = "Message";
-
-  parameters["huburl"] = param1;
-  parameters["message"] = param2;
-  root["parameters"] = parameters;
-
-  returns["type"] = "integer";
-  returns["description"] = "Return 0 on success and 1 on failed";
-  root["returns"] = returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionHubSayPM() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2,param3;
-  Json::Value returns;
-
-  root["description"] = "Send private message to nick on hub url";
-  param1["type"] = "string";
-  param1["description"] = "Hub url";
-  param2["type"] = "string";
-  param2["description"] = "Nick";
-  param3["type"] = "string";
-  param3["description"] = "Message";
-
-  parameters["huburl"] = param1;
-  parameters["nick"] = param2;
-  parameters["message"] = param3;
-  root["parameters"] = parameters;
-
-  returns["type"] = "integer";
-  returns["description"] = "Return 0 on success and 1 on failed";
-  root["returns"] = returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionListHubs() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1;
-  Json::Value returns;
-  
-  root["description"] = "Get list of hubs";
-  param1["type"] = "string";
-  param1["description"] = "Separator";
-
-  parameters["separator"] = param1;
-  root["parameters"] = parameters;
-
-  returns["type"] = "integer";
-  returns["description"] = "Return 0 on success and 1 on failed";
-  root["returns"] = returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionAddDirInShare() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-
-  root["description"] = "Add directory in share with virtual name";
-  param1["type"] = "string";
-  param1["description"] = "Directory";
-  param2["type"] = "string";
-  param2["description"] = "VirtualName";
-
-  parameters["directory"] = param1;
-  parameters["virtname"] = param2;
-  root["parameters"] = parameters;
-
-  returns["type"] = "integer or string";
-  returns["description"] = "Return 0 on success and 1 on failed or shareexception";
-  root["returns"] = returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionRenameDirInShare() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  
-  root["description"] = "Rename directory in share";
-  param1["type"] = "string";
-  param1["description"] = "Directory";
-  param2["type"] = "string";
-  param2["description"] = "VirtualName";
-
-  parameters["directory"] = param1;
-  parameters["virtname"] = param2;
-  root["parameters"] = parameters;
-
-  returns["type"] = "integer or string";
-  returns["description"] = "Return 0 on success and 1 on failed or shareexception";
-  root["returns"] = returns;
-  
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionDelDirFromShare() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1;
-  Json::Value returns;
-  
-  root["description"] = "Delete directory from share";
-  param1["type"] = "string";
-  param1["description"] = "Directory";
-
-  parameters["directory"] = param1;
-  root["parameters"] = parameters;
-
-  returns["type"] = "integer or string";
-  returns["description"] = "Return 0 on success and 1 on failed or shareexception";
-  root["returns"] = returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionListShare() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1;
-  Json::Value returns;
-  
-  root["description"] = "Return list share";
-  param1["type"] = "string";
-  param1["description"] = "Separator";
-
-  parameters["separator"] = param1;
-  root["parameters"] = parameters;
-
-  returns["type"] = "string";
-  returns["description"] = "Return list share";
-  root["returns"] = returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionRefreshShare() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value returns;
-  
-  root["description"] = "Run refresh share";
-  root["parameters"] = Json::Value::null;
-
-  returns["type"] = "integer";
-  returns["description"] = "Return 0";
-  root["returns"] = returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionGetFileList() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionGetChatPub() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-
-  root["description"] = "Return chat from huburl";
-  param1["type"] = "string";
-  param1["description"] = "Hub url";
-  param2["type"] = "string";
-  param2["description"] = "Separator";
-
-  parameters["huburl"] = param1;
-  parameters["separator"] = param2;
-  root["parameters"] = parameters;
-
-  returns["type"] = "string";
-  returns["description"] = "Return chat from hub url";
-  root["returns"] = returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionSendSearch() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionReturnSearchResults() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionShowVersion() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionShowRatio() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionSetPriorityQueueItem() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionMoveQueueItem() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionRemoveQueueItem() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionListQueueTargets() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionListQueue() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionClearSearchResults() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionAddQueueItem() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionGetSourcesItem() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionGetHashStatus() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
-}
-Json::Value JsonRpcMethods::GetDescriptionPauseHash() {
-  Json::FastWriter writer;
-  Json::Value root;
-  Json::Value parameters;
-  Json::Value param1,param2;
-  Json::Value returns;
-  return root;
+bool JsonRpcMethods::GetUserInfo(const Json::Value& root, Json::Value& response) {
+    if (isDebug) std::cout << "GetUserInfo (root): " << root << std::endl;
+    response["jsonrpc"] = "2.0";
+    response["id"] = root["id"];
+    StringMap tmp; Json::Value parameters;
+    if (ServerThread::getInstance()->getUserInfo(tmp, root["params"]["nick"].asString(),root["params"]["huburl"].asString())) {
+        for (StringMap::iterator kk = tmp.begin(); kk != tmp.end(); ++kk) {
+            parameters[kk->first] = kk->second;
+        }
+    }
+    response["result"] = parameters;
+    if (isDebug) std::cout << "GetUserInfo (response): " << response << std::endl;
+    return true;
 }
