@@ -235,15 +235,9 @@ int main(int argc, char* argv[])
     sTitle += " [debug]";
 #endif
 
-    if (bDaemon) {
-        if (!Util::fileExists(LOG_FILE)) {
-            logging(false, false, false, string("ERROR: Daemon log: No such file or directory (") + LOG_FILE.c_str()+ string(")"));
-        }
-    }
-
     Util::PathsMap override;
 
-    if (config_dir[0] != 0) {
+    if (config_dir[0]) {
         string tmp(config_dir);
         tmp = tmp.substr(tmp.size()-1, tmp.size()) == PATH_SEPARATOR_STR ? tmp : tmp + PATH_SEPARATOR_STR;
         override[Util::PATH_USER_CONFIG] = tmp;
@@ -252,7 +246,7 @@ int main(int argc, char* argv[])
             logging(bDaemon, bsyslog, false, string("ERROR: Config directory: No such file or directory (" + string(config_dir) + ")"));
         }
     }
-    if (local_dir[0] != 0) {
+    if (local_dir[0]) {
         string tmp(local_dir);
         tmp = tmp.substr(tmp.size()-1, tmp.size()) == PATH_SEPARATOR_STR ? tmp : tmp + PATH_SEPARATOR_STR;
         override[Util::PATH_USER_LOCAL] = tmp;
@@ -288,12 +282,26 @@ int main(int argc, char* argv[])
 
     PATH = Util::getPath(Util::PATH_USER_CONFIG);
     LOCAL_PATH = Util::getPath(Util::PATH_USER_LOCAL);
+
+    if (LOG_FILE.empty())
+#ifdef _WIN32
+        LOG_FILE = PATH + "logs\\daemon.log";
+#else
+        LOG_FILE = PATH + "Logs/daemon.log";
+#endif
+
+    if (bDaemon) {
+        if (!Util::fileExists(LOG_FILE)) {
+            logging(false, false, false, string("ERROR: Daemon log: No such file or directory (") + LOG_FILE.c_str()+ string(")"));
+        }
+    }
+
 #ifndef _WIN32
     if (bDaemon) {
         if (eidcpp_daemon(true,false) == -1)
             return EXIT_FAILURE;
 
-        if (pidfile[0] != 0)
+        if (pidfile[0])
             writePidFile(pidfile);
     }
 #endif
