@@ -445,7 +445,11 @@ void FinishedTransfers::onShowOnlyFullFilesToggled_gui(GtkWidget *widget, gpoint
     StringMap params;
     gtk_list_store_clear(ft->fileStore);
 
+#ifdef DO_NOT_USE_MUTEX
     FinishedManager::getInstance()->lockLists();
+#else // DO_NOT_USE_MUTEX
+    auto lock = FinishedManager::getInstance()->lockLists();
+#endif // DO_NOT_USE_MUTEX
 
     const FinishedManager::MapByFile &list = FinishedManager::getInstance()->getMapByFile(ft->isUpload);
 
@@ -455,8 +459,9 @@ void FinishedTransfers::onShowOnlyFullFilesToggled_gui(GtkWidget *widget, gpoint
         ft->getFinishedParams_client(it->second, it->first, params);
         ft->addFile_gui(params, FALSE);
     }
-
+#ifdef DO_NOT_USE_MUTEX
     FinishedManager::getInstance()->unlockLists();
+#endif // DO_NOT_USE_MUTEX
 }
 
 void FinishedTransfers::onOpen_gui(GtkMenuItem *item, gpointer data)
@@ -630,9 +635,11 @@ void FinishedTransfers::onRemoveAll_gui(GtkMenuItem *item, gpointer data)
 void FinishedTransfers::initializeList_client()
 {
     StringMap params;
-    typedef Func2<FinishedTransfers, StringMap, bool> F2;
-    //F2 *func;
+#ifdef DO_NOT_USE_MUTEX
     FinishedManager::getInstance()->lockLists();
+#else // DO_NOT_USE_MUTEX
+    auto lock = FinishedManager::getInstance()->lockLists();
+#endif // DO_NOT_USE_MUTEX
     const FinishedManager::MapByFile &list = FinishedManager::getInstance()->getMapByFile(isUpload);
     const FinishedManager::MapByUser &user = FinishedManager::getInstance()->getMapByUser(isUpload);
 
@@ -641,8 +648,6 @@ void FinishedTransfers::initializeList_client()
         params.clear();
         getFinishedParams_client(it->second, it->first, params);
         addFile_gui(params, FALSE);
-        //func = new F2(this, &FinishedTransfers::addItem_gui, params, FALSE);
-        //WulforManager::get()->dispatchGuiFunc(func);
     }
 
     for (auto uit = user.begin(); uit != user.end(); ++uit)
@@ -650,14 +655,13 @@ void FinishedTransfers::initializeList_client()
         params.clear();
         getFinishedParams_client(uit->second, uit->first, params);
         addUser_gui(params, FALSE);
-        //func = new F2(this, &FinishedTransfers::addItem_gui, params, FALSE);
-        //WulforManager::get()->dispatchGuiFunc(func);
     }
 
+#ifdef DO_NOT_USE_MUTEX
     FinishedManager::getInstance()->unlockLists();
+#endif // DO_NOT_USE_MUTEX
 
     updateStatus_gui();
-    //WulforManager::get()->dispatchGuiFunc(new Func0<FinishedTransfers>(this, &FinishedTransfers::updateStatus_gui));
 }
 
 void FinishedTransfers::getFinishedParams_client(const FinishedFileItemPtr& item, const string& file, StringMap &params)
