@@ -123,7 +123,7 @@ MainWindow::MainWindow():
     } else
         g_object_set(G_OBJECT(child), "icon-size", GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
 
-    if (WGETI("toolbar-position") == 0)
+    if (!WGETI("toolbar-position"))
     {
         box = GTK_BOX(getWidget("vbox1"));
         gtk_orientable_set_orientation(GTK_ORIENTABLE(child), GTK_ORIENTATION_HORIZONTAL);
@@ -194,7 +194,7 @@ MainWindow::MainWindow():
     GtkIconTheme *iconTheme = gtk_icon_theme_get_default();
     GdkPixbuf *logo = gtk_icon_theme_load_icon(iconTheme, "eiskaltdcpp", 128, GTK_ICON_LOOKUP_FORCE_SVG, NULL);
 
-    if (logo != NULL)
+    if (logo)
     {
         gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(getWidget("aboutDialog")), logo);
         g_object_unref(logo);
@@ -236,6 +236,7 @@ MainWindow::MainWindow():
         string("\n")+
         _("Ukrainian translation\n")+
         string("  2010 Dmytro Demenko <dmytro.demenko@gmail.com>\n")+
+        string("  2013 gray aka grayich <grayich@ukr.net>\n")+
         string("\n")+
         _("Serbian (Latin) translation\n")+
         string("  2010-2013 Miroslav Petrovic <miroslav031@gmail.com>\n")+
@@ -660,7 +661,7 @@ void MainWindow::removeBookEntry_gui(BookEntry *entry)
         if (num == gtk_notebook_get_current_page(book))
         {
             GList *prev = g_list_first(list);
-            if (prev != NULL)
+            if (prev)
             {
                 gint childNum = gtk_notebook_page_num(book, GTK_WIDGET(prev->data));
                 gtk_notebook_set_current_page(book, childNum);
@@ -670,7 +671,7 @@ void MainWindow::removeBookEntry_gui(BookEntry *entry)
 
         removeTabMenuItem_gui(menuItem);
 
-        if (gtk_notebook_get_n_pages(book) == 0)
+        if (!gtk_notebook_get_n_pages(book))
         {
             gtk_widget_set_sensitive(getWidget("closeMenuItem"), FALSE);
             setTitle(""); // Reset window title to default
@@ -682,7 +683,7 @@ void MainWindow::previousTab_gui()
 {
     GtkNotebook *book = GTK_NOTEBOOK(getWidget("book"));
 
-    if (gtk_notebook_get_current_page(book) == 0)
+    if(!gtk_notebook_get_current_page(book))
         gtk_notebook_set_current_page(book, -1);
     else
         gtk_notebook_prev_page(book);
@@ -715,7 +716,7 @@ void MainWindow::removeTabMenuItem_gui(GtkWidget *menuItem)
 
     gtk_container_remove(GTK_CONTAINER(getWidget("tabsMenu")), menuItem);
 
-    if (gtk_notebook_get_n_pages(book) == 0)
+    if (!gtk_notebook_get_n_pages(book))
     {
         gtk_widget_set_sensitive(getWidget("previousTabMenuItem"), FALSE);
         gtk_widget_set_sensitive(getWidget("nextTabMenuItem"), FALSE);
@@ -786,7 +787,7 @@ void MainWindow::showDownloadQueue_gui()
 {
     BookEntry *entry = findBookEntry(Entry::DOWNLOAD_QUEUE);
 
-    if (entry == NULL)
+    if (!entry)
     {
         entry = new DownloadQueue();
         addBookEntry_gui(entry);
@@ -799,7 +800,7 @@ void MainWindow::showFavoriteHubs_gui()
 {
     BookEntry *entry = findBookEntry(Entry::FAVORITE_HUBS);
 
-    if (entry == NULL)
+    if (!entry)
     {
         entry = new FavoriteHubs();
         addBookEntry_gui(entry);
@@ -812,7 +813,7 @@ void MainWindow::showFavoriteUsers_gui()
 {
     BookEntry *entry = findBookEntry(Entry::FAVORITE_USERS);
 
-    if (entry == NULL)
+    if (!entry)
     {
         entry = new FavoriteUsers();
         addBookEntry_gui(entry);
@@ -825,7 +826,7 @@ void MainWindow::showFinishedDownloads_gui()
 {
     BookEntry *entry = findBookEntry(Entry::FINISHED_DOWNLOADS);
 
-    if (entry == NULL)
+    if (!entry)
     {
         entry = FinishedTransfers::createFinishedDownloads();
         addBookEntry_gui(entry);
@@ -838,7 +839,7 @@ void MainWindow::showFinishedUploads_gui()
 {
     BookEntry *entry = findBookEntry(Entry::FINISHED_UPLOADS);
 
-    if (entry == NULL)
+    if (!entry)
     {
         entry = FinishedTransfers::createFinishedUploads();
         addBookEntry_gui(entry);
@@ -851,7 +852,7 @@ void MainWindow::showHub_gui(string address, string encoding)
 {
     BookEntry *entry = findBookEntry(Entry::HUB, address);
 
-    if (entry == NULL)
+    if (!entry)
     {
         entry = new Hub(address, encoding);
         addBookEntry_gui(entry);
@@ -866,7 +867,7 @@ void MainWindow::showSearchSpy_gui()
 {
         BookEntry *entry = findBookEntry(Entry::SEARCH_SPY);
 
-        if (entry == NULL)
+        if (!entry)
         {
                 entry = new SearchSpy();
                 addBookEntry_gui(entry);
@@ -879,7 +880,7 @@ void MainWindow::showSearchADL_gui()
 {
         BookEntry *entry = findBookEntry(Entry::SEARCH_ADL);
 
-        if (entry == NULL)
+        if (!entry)
         {
                 entry = new SearchADL();
                 addBookEntry_gui(entry);
@@ -892,7 +893,7 @@ void MainWindow::showCmdDebug_gui()
 {
    BookEntry *entry = findBookEntry(Entry::CMD);
 
-   if(entry == NULL)
+   if (!entry)
    {
        entry = new cmddebug();
        addBookEntry_gui(entry);
@@ -909,9 +910,9 @@ void MainWindow::addPrivateMessage_gui(Msg::TypeMsg typemsg, string cid, string
 
     // If PM is initiated by another user, use setting except if tab is already open.
     if (useSetting)
-        raise = (entry == NULL) ? !WGETB("popunder-pm") : FALSE;
+        raise = (!entry ? !WGETB("popunder-pm") : FALSE);
 
-    if (entry == NULL)
+    if (!entry)
     {
         entry = new PrivateMessage(cid, hubUrl);
         addBookEntry_gui(entry);
@@ -928,7 +929,7 @@ void MainWindow::addPrivateMessage_gui(Msg::TypeMsg typemsg, string cid, string
         if (!isActive_gui())
         {
             show = TRUE;
-            if (useStatusIconBlink && timer == 0)
+            if (useStatusIconBlink && !timer)
             {
                 timer = g_timeout_add(1000, animationStatusIcon_gui, (gpointer)this);
             }
@@ -983,7 +984,7 @@ void MainWindow::addPrivateStatusMessage_gui(Msg::TypeMsg typemsg, string cid, s
 {
     BookEntry *entry = findBookEntry(Entry::PRIVATE_MESSAGE, cid);
 
-    if (entry != NULL)
+    if (entry)
         dynamic_cast<PrivateMessage*>(entry)->addStatusMessage_gui(message, typemsg);
 }
 
@@ -991,7 +992,7 @@ void MainWindow::showPublicHubs_gui()
 {
     BookEntry *entry = findBookEntry(Entry::PUBLIC_HUBS);
 
-    if (entry == NULL)
+    if (!entry)
     {
         entry = new PublicHubs();
         addBookEntry_gui(entry);
@@ -1005,7 +1006,7 @@ void MainWindow::showShareBrowser_gui(UserPtr user, string filename, string dir,
     bool raise = useSetting ? !WGETB("popunder-filelist") : TRUE;
     BookEntry *entry = findBookEntry(Entry::SHARE_BROWSER, user->getCID().toBase32());
 
-    if (entry == NULL)
+    if (!entry)
     {
         entry = new ShareBrowser(user, filename, dir, true);
         addBookEntry_gui(entry);
@@ -1068,7 +1069,7 @@ void MainWindow::actionMagnet_gui(string magnet)
     int action = WGETI("magnet-action");
     bool split = WulforUtil::splitMagnet(magnet, name, size, tth);
 
-    if (action == 0 && split)
+    if (!action && split)
     {
         Search *s = addSearch_gui();
         if (tth != _("Unknown"))
@@ -1523,7 +1524,7 @@ gboolean MainWindow::onWindowState_gui(GtkWidget *widget, GdkEventWindowState *e
             Util::setAway(TRUE);
     }
     else if (mw->minimized && (event->new_window_state & GDK_WINDOW_STATE_MAXIMIZED ||
-        event->new_window_state == 0))
+                              !event->new_window_state))
     {
         mw->minimized = FALSE;
         if (BOOLSETTING(SettingsManager::AUTO_AWAY) && !Util::getManualAway())
@@ -1538,7 +1539,7 @@ gboolean MainWindow::onFocusIn_gui(GtkWidget *widget, GdkEventFocus *event, gpoi
     MainWindow *mw = (MainWindow *)data;
     GtkWidget *child = mw->currentPage_gui();
 
-    if (child != NULL)
+    if (child)
     {
         BookEntry *entry = (BookEntry *)g_object_get_data(G_OBJECT(child), "entry");
         entry->setActive_gui();
@@ -1906,13 +1907,13 @@ void MainWindow::onPreferencesClicked_gui(GtkWidget *widget, gpointer data)
         {
             BookEntry *entry = mw->findBookEntry(Entry::HUB, *it);
 
-            if (entry != NULL)
+            if (entry)
                 dynamic_cast<Hub*>(entry)->preferences_gui();
             else
             {
                 entry = mw->findBookEntry(Entry::PRIVATE_MESSAGE, *it);
 
-                if (entry != NULL)
+                if (entry)
                     dynamic_cast<PrivateMessage*>(entry)->preferences_gui();
             }
         }
@@ -1920,7 +1921,7 @@ void MainWindow::onPreferencesClicked_gui(GtkWidget *widget, gpointer data)
         // Search Spy
         BookEntry *entry = mw->findBookEntry(Entry::SEARCH_SPY);
 
-        if (entry != NULL)
+        if (entry)
             dynamic_cast<SearchSpy *>(entry)->preferences_gui();
 
         // Status menu
@@ -2340,7 +2341,7 @@ void MainWindow::on(TimerManagerListener::Second, uint64_t ticks) noexcept
     if (!WGETB("always-tray") && minimized)
         return;
 
-    int64_t diff = (int64_t)((lastUpdate == 0) ? ticks - 1000 : ticks - lastUpdate);
+    int64_t diff = (int64_t)(!lastUpdate ? ticks - 1000 : ticks - lastUpdate);
     int64_t downDiff = Socket::getTotalDown() - lastDown;
     int64_t upDiff = Socket::getTotalUp() - lastUp;
     int64_t downBytes = 0;
@@ -2433,7 +2434,7 @@ void MainWindow::onTTHFileButton_gui(GtkWidget *widget , gpointer data)
         File f(Text::fromT(string(temp)),File::READ, File::OPEN);
         HashManager  *HM = HashManager::getInstance();
         const TTHValue *tth= HM->getFileTTHif(string(temp));
-        if (tth != NULL) {
+        if (tth) {
             TTH = tth->toBase32();
             string magnetlink = "magnet:?xt=urn:tree:tiger:" + TTH +"&xl="+Util::toString(f.getSize())+"&dn="+Util::encodeURI(Text::fromT(Util::getFileName(string(temp))));
             f.close();
@@ -2475,7 +2476,7 @@ void MainWindow::onCloseAllHub_gui(GtkWidget *widget, gpointer data)
     typedef Func1<MainWindow,BookEntry*> F1;
     for (StringIterC it = mw->EntryList.begin(); it != mw->EntryList.end(); ++it) {
         BookEntry *entry = mw->findBookEntry(Entry::HUB, *it);
-        if (entry != NULL) {
+        if (entry) {
             F1 *func = new F1(mw,&MainWindow::removeBookEntry_gui,entry);
             WulforManager::get()->dispatchGuiFunc(func);
         }
@@ -2488,7 +2489,7 @@ void MainWindow::onCloseAllPM_gui(GtkWidget *widget, gpointer data)
     typedef Func1<MainWindow,BookEntry*> F1;
     for (StringIterC it = mw->EntryList.begin(); it != mw->EntryList.end(); ++it) {
         BookEntry *entry = mw->findBookEntry(Entry::PRIVATE_MESSAGE, *it);
-        if (entry != NULL) {
+        if (entry) {
             F1 *func = new F1(mw,&MainWindow::removeBookEntry_gui,entry);
             WulforManager::get()->dispatchGuiFunc(func);
         }
@@ -2501,7 +2502,7 @@ void MainWindow::onCloseAllSearch_gui(GtkWidget *widget, gpointer data)
     typedef Func1<MainWindow,BookEntry*> F1;
     for (StringIterC it = mw->EntryList.begin(); it != mw->EntryList.end(); ++it) {
         BookEntry *entry = mw->findBookEntry(Entry::SEARCH, *it);
-        if (entry != NULL) {
+        if (entry) {
             F1 *func = new F1(mw,&MainWindow::removeBookEntry_gui,entry);
             WulforManager::get()->dispatchGuiFunc(func);
         }
@@ -2514,7 +2515,7 @@ void MainWindow::onReconectAllHub_gui(GtkWidget *widget, gpointer data)
     typedef Func1<MainWindow,BookEntry*> F1;
     for (StringIterC it = mw->EntryList.begin(); it != mw->EntryList.end(); ++it) {
         BookEntry *entry = mw->findBookEntry(Entry::HUB, *it);
-        if (entry != NULL) {
+        if (entry) {
             dynamic_cast<Hub*>(entry)->reconnect_client();
         }
     }
@@ -2526,7 +2527,7 @@ void MainWindow::onCloseAlloffPM_gui(GtkWidget *widget, gpointer data)
     typedef Func1<MainWindow,BookEntry*> F1;
     for (StringIterC it = mw->EntryList.begin(); it != mw->EntryList.end(); ++it) {
         BookEntry *entry = mw->findBookEntry(Entry::PRIVATE_MESSAGE, *it);
-        if (entry != NULL && dynamic_cast<PrivateMessage*>(entry)->getIsOffline()) {
+        if (entry && dynamic_cast<PrivateMessage*>(entry)->getIsOffline()) {
             F1 *func = new F1(mw,&MainWindow::removeBookEntry_gui,entry);
             WulforManager::get()->dispatchGuiFunc(func);
         }
@@ -2543,7 +2544,7 @@ void MainWindow::showUploadQueue_gui()
 {
     BookEntry *entry = findBookEntry(Entry::UPLOADQUEUE);
 
-    if(entry == NULL)
+    if(!entry)
     {
         entry = new UploadQueue();
         addBookEntry_gui(entry);
@@ -2567,13 +2568,13 @@ void MainWindow::parsePartial_gui(HintedUser user, string txt)
     //string path = QueueManager::getInstance()->getListPath(aUser) + ".xml.bz2";
     string path = Util::getListPath() + nick + user.user->getCID().toBase32() + ".xml.bz2";
 
-    if(entry != NULL)
+    if (entry)
     {
-      dynamic_cast<ShareBrowser*>(entry)->loadXML(txt);
+        dynamic_cast<ShareBrowser*>(entry)->loadXML(txt);
     }
     else
     {
-        if (entry == NULL && !path.empty())
+        if (!entry && !path.empty())
         {
             entry = new ShareBrowser(user.user, path, "", false);
             addBookEntry_gui(entry);
