@@ -144,7 +144,7 @@ ShareBrowser::ShareBrowser(UserPtr user, const string &file, const string &initi
 #if !GLIB_CHECK_VERSION(2,32,0)
     GError *error = NULL;
     g_thread_create(threadLoad_list, (gpointer)this, FALSE, &error);
-    if (error != NULL)
+    if (error)
     {
         cerr << "Unable to create filelist loader thread: " << error->message << endl;
         g_error_free(error);
@@ -343,7 +343,7 @@ void ShareBrowser::updateFiles_gui(DirectoryListing::Directory *dir)
 
         // If ext is empty we cannot do substr on it.
         string ext = Util::getFileExt((*it_file)->getName());
-        if (ext.length() > 0)
+        if(!ext.empty())
             ext = ext.substr(1);
 
         gtk_list_store_set(fileStore, &iter,
@@ -428,7 +428,7 @@ void ShareBrowser::fileViewSelected_gui()
             while (valid && ptr != dirView.getValue<gpointer>(&iter, "DL Dir"))
                 valid = gtk_tree_model_iter_next(m, &iter);
 
-            if (!full && filesize == 0) {
+            if (!full && !filesize) {
                 typedef Func1<ShareBrowser, DirectoryListing::Directory*> F1;
                 F1 *func = new F1(this,&ShareBrowser::downloadChangedDir,
                 (DirectoryListing::Directory *)dirView.getValue<gpointer>(&iter, "DL Dir"));
@@ -643,7 +643,7 @@ void ShareBrowser::find_gui()
     GtkTreeModel *m = GTK_TREE_MODEL(dirStore);
     GtkTreePath *dirPath = gtk_tree_path_new_first();
 
-    if (gtk_tree_path_get_depth(dirPath) == 0 || !gtk_tree_model_get_iter(m, &iter, dirPath))
+    if (!gtk_tree_path_get_depth(dirPath) || !gtk_tree_model_get_iter(m, &iter, dirPath))
     {
         gtk_tree_path_free(dirPath);
         return;
@@ -686,7 +686,7 @@ void ShareBrowser::find_gui()
         }
 
         // Come back up one directory. If we can't, then we've returned to the root and are done.
-        if (!gtk_tree_path_up(dirPath) || gtk_tree_path_get_depth(dirPath) == 0 ||
+        if (!gtk_tree_path_up(dirPath) || !gtk_tree_path_get_depth(dirPath) ||
             !gtk_tree_model_get_iter(m, &iter, dirPath))
         {
             setStatus_gui("mainStatus", _("No matches"));
@@ -1135,7 +1135,7 @@ void ShareBrowser::onDirGet(GtkMenuItem* item, gpointer data)
             {
                 if(!ii->file->getAdls())return;
                 DirectoryListing::Directory *dir=ii->file->getParent();
-                while( (dir!=NULL) && (dir!=sb->listing.getRoot()))
+                while( dir && (dir != sb->listing.getRoot()))
                 {
                     fullpath=dir->getName()+PATH_SEPARATOR+fullpath;
                     dir=dir->getParent();
