@@ -69,14 +69,14 @@ GtkTreeView *TreeView::get()
  */
 string TreeView::getString(GtkTreeIter *i, const string &column, GtkTreeModel *m)
 {
-    if (m == NULL)
+    if(!m)
         m = gtk_tree_view_get_model(view);
     string value;
     gchar* temp;
     dcassert(gtk_tree_model_get_column_type(m, col(column)) == G_TYPE_STRING);
     gtk_tree_model_get(m, i, col(column), &temp, -1);
 
-    if (temp != NULL)
+    if (temp)
     {
         value = string(temp);
         g_free(temp);
@@ -188,7 +188,7 @@ int TreeView::getRowCount()
 GType* TreeView::getGTypes()
 {
     int i = 0;
-    if (gtypes != NULL)
+    if (gtypes)
         return gtypes;
     gtypes = new GType[count];
 
@@ -485,7 +485,7 @@ void TreeView::saveSettings()
     for (size_t i = 0; i < columns.size(); i++)
     {
         col = gtk_tree_view_get_column(view, i);
-        if (col == NULL)
+        if (!col)
             continue;
 
         title = string(gtk_tree_view_column_get_title(col));
@@ -503,7 +503,7 @@ void TreeView::saveSettings()
         columnVisibility += dcpp::Util::toString(gtk_tree_view_column_get_visible(col)) + ",";
     }
 
-    if (columnOrder.size() > 0)
+    if (!columnOrder.empty())
     {
         columnOrder.erase(columnOrder.size() - 1, 1);
         columnWidth.erase(columnWidth.size() - 1, 1);
