@@ -22,7 +22,6 @@
 #include "wulformanager.hh"
 #include "WulforUtil.hh"
 #include <iostream>
-#include <gdk/gdkx.h>
 #include <glib/gi18n.h>
 #include "hashdialog.hh"
 #include "settingsdialog.hh"
@@ -111,7 +110,7 @@ WulforManager::WulforManager()
 #if !GLIB_CHECK_VERSION(2,32,0)
     GError *error = NULL;
     guiThread = g_thread_create(threadFunc_gui, (gpointer)this, TRUE, &error);
-    if (error != NULL)
+    if (error)
     {
         cerr << "Unable to create gui thread: " << error->message << endl;
         g_error_free(error);
@@ -121,7 +120,7 @@ WulforManager::WulforManager()
     g_clear_error(&error);
 
     clientThread = g_thread_create(threadFunc_client, (gpointer)this, TRUE, &error);
-    if (error != NULL)
+    if (error)
     {
         cerr << "Unable to create client thread: " << error->message << endl;
         g_error_free(error);
@@ -213,11 +212,11 @@ void WulforManager::deleteMainWindow()
     DialogEntry *hashDialogEntry = getHashDialog_gui();
     DialogEntry *settingsDialogEntry = getSettingsDialog_gui();
 
-    if (hashDialogEntry != NULL)
+    if (hashDialogEntry)
     {
         gtk_dialog_response(GTK_DIALOG(hashDialogEntry->getContainer()), GTK_RESPONSE_OK);
     }
-    if (settingsDialogEntry != NULL)
+    if (settingsDialogEntry)
     {
         dynamic_cast<Settings*>(settingsDialogEntry)->response_gui();
     }
@@ -269,9 +268,6 @@ void WulforManager::processGuiQueue()
         }
         g_mutex_unlock(guiQueueMutex);
 
-        // Don't call gdk_flush() since it actually calls XSync, which can
-        // block waiting on events
-        XFlush(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()));
         gdk_threads_leave();
     }
 
