@@ -242,6 +242,13 @@ friend class dcpp::Singleton<MainWindow>;
         void slotUpdateFavHubMenu();
         void slotConnectFavHub(QAction*);
 
+        // These slots are used only in Mac OS X.
+        // But due to bug in moc they cannot be placed in #ifdef block.
+        void slotShowSpeedLimits();
+        void slotSupressTxt();
+        void slotSupressSnd();
+        //
+
     Q_SIGNALS:
         void coreLogMessage(const QString&);
         void coreOpenShare(dcpp::UserPtr, const QString &, const QString&);
@@ -263,6 +270,7 @@ friend class dcpp::Singleton<MainWindow>;
         void init();
         void loadSettings();
         void saveSettings();
+        void getWindowGeometry();
 
         void initActions();
         void initMenuBar();
@@ -271,6 +279,9 @@ friend class dcpp::Singleton<MainWindow>;
         void initToolbar();
         void initSideBar();
         void initFavHubMenu();
+#if defined(Q_WS_MAC)
+        void initDockMenuBar();
+#endif
 
         void toggleSingletonWidget(ArenaWidget *a);
 
