@@ -307,7 +307,7 @@ SearchFrame::Menu::Action SearchFrame::Menu::exec(QStringList list = QStringList
     QMenu *userm = buildUserCmdMenu(list);
 
     if (userm)
-        if (userm->actions().size() > 0)
+        if (!userm->actions().isEmpty())
             menu->addMenu(userm);
 
     QAction *ret = menu->exec(QCursor::pos());
@@ -1037,7 +1037,7 @@ void SearchFrame::slotStartSearch(){
 
     SearchManager::SizeModes searchMode((SearchManager::SizeModes)comboBox_SIZETYPE->currentIndex());
 
-    if(llsize == 0 || lineEdit_SIZE->text() == "")
+    if(!llsize || lineEdit_SIZE->text() == "")
         searchMode = SearchManager::SIZE_DONTCARE;
 
     int ftype = comboBox_FILETYPES->currentIndex();
@@ -1098,6 +1098,8 @@ void SearchFrame::slotStartSearch(){
 
     d->arena_title = tr("Search - %1").arg(s);
 
+    lineEdit_SEARCHSTR->setEnabled(false);
+
     MW->redrawToolPanel();
 }
 
@@ -1538,7 +1540,7 @@ void SearchFrame::slotContextMenu(const QPoint &){
                 if (getDownloadParams(params, item))
                     new_inst << item->data(COLUMN_SF_FILENAME).toString();
             }
-            if (new_inst.size()>0){
+            if (!new_inst.isEmpty()){
                 static SearchBlacklist *SB = SearchBlacklist::getInstance();
                 QList <QString> list = SB->getList(SearchBlacklist::NAME);
                 list.append(new_inst);
@@ -1575,9 +1577,10 @@ void SearchFrame::slotTimer(){
         QString msg = "";
         progressBar->setFormat(msg);
         progressBar->setValue(0);
+        lineEdit_SEARCHSTR->setEnabled(true);
     }
 
-    if (d->dropped == d->results && d->dropped == 0){
+    if (d->dropped == d->results && !d->dropped){
 
         if (d->currentSearch.empty())
             frame_PROGRESS->hide();
@@ -1665,7 +1668,7 @@ void SearchFrame::slotSettingsChanged(const QString &key, const QString &value){
 void SearchFrame::on(SearchManagerListener::SR, const dcpp::SearchResultPtr& aResult) noexcept {
     Q_D(SearchFrame);
 
-    if (d->currentSearch.empty() || aResult == NULL || d->stop == true)
+    if (d->currentSearch.empty() || !aResult || d->stop == true)
         return;
 
     if (!aResult->getToken().empty() && d->token != _q(aResult->getToken())){
@@ -1704,7 +1707,7 @@ void SearchFrame::on(SearchManagerListener::SR, const dcpp::SearchResultPtr& aRe
         }
     }
 
-    if (d->withFreeSlots && aResult->getFreeSlots() == 0){
+    if (d->withFreeSlots && !aResult->getFreeSlots()){
         d->dropped++;
 
         return;
@@ -1736,4 +1739,5 @@ void SearchFrame::slotStopSearch(){
     Q_D(SearchFrame);
 
     d->stop = true;
+    d->waitingResults = false;
 }
