@@ -68,7 +68,8 @@ TransferView::Menu::Menu():
 
     copy_column->addAction(tr("Users"));
     copy_column->addAction(tr("Speed"));
-    copy_column->addAction(tr("Statistic"));
+    copy_column->addAction(tr("Status"));
+    copy_column->addAction(tr("Flags"));
     copy_column->addAction(tr("Size"));
     copy_column->addAction(tr("Time left"));
     copy_column->addAction(tr("Filename"));
@@ -342,6 +343,21 @@ void TransferView::downloadComplete(QString target){
     Notification::getInstance()->showMessage(Notification::TRANSFER, tr("Download complete"), target);
 }
 
+QString TransferView::getTTHFromItem(const TransferViewItem *item){
+    QString tth_str = "";
+
+    if (item->download)
+        tth_str = item->tth;
+    else {
+        const TTHValue *tth = dcpp::HashManager::getInstance()->getFileTTHif(_tq(item->target));
+
+        if (tth)
+            tth_str = _q(tth->toBase32());
+    }
+
+    return tth_str;
+}
+
 void TransferView::getParams(TransferView::VarMap &params, const dcpp::ConnectionQueueItem *item){
     const dcpp::UserPtr &user = item->getUser();
     WulforUtil *WU = WulforUtil::getInstance();
@@ -452,20 +468,9 @@ void TransferView::slotContextMenu(const QPoint &){
         QString tth_str = "";
         std::for_each(items.begin(), items.end(), 
                       [&](const TransferViewItem *item) {
-                          tth_str = "";
-                          
-                          if (item->download)
-                            tth_str = item->tth;
-                          else {
-                            const TTHValue *tth = dcpp::HashManager::getInstance()->getFileTTHif(_tq(item->target));
-                
-                            if (tth)
-                                tth_str = _q(tth->toBase32());
-                          }
-                          
+                          tth_str = getTTHFromItem(item);
                           if (!tth_str.isEmpty() && !tths.contains(tth_str)){
                             tths.push_back(tth_str);
-                              
                             searchAlternates(tth_str);
                           }
                       }
@@ -504,16 +509,21 @@ void TransferView::slotContextMenu(const QPoint &){
                 data += i->data(col).toString() + "\n";
         }
         else {
+            QString tth_str = "";
             foreach(TransferViewItem *i, items){
-                const TTHValue *tth = HashManager::getInstance()->getFileTTHif(_tq(i->target));
                 QFileInfo fi(i->target);
+                tth_str = getTTHFromItem(i);
 
-                if ( tth == NULL ) {
+                if (tth_str.isEmpty()) {
                     QString str = QDir::toNativeSeparators(fi.canonicalFilePath() ); // try to follow symlinks
-                    tth = HashManager::getInstance()->getFileTTHif(str.toStdString());
+                    const TTHValue *tth = HashManager::getInstance()->getFileTTHif(str.toStdString());
+
+                    if (tth)
+                        tth_str = _q(tth->toBase32());
                 }
-                if (tth != NULL)
-                    data += WulforUtil::getInstance()->makeMagnet(fi.fileName(), fi.size(), _q(tth->toBase32())) + "\n";
+
+                if (!tth_str.isEmpty())
+                    data += WulforUtil::getInstance()->makeMagnet(fi.fileName(), fi.size(), tth_str) + "\n";
             }
         }
 
