@@ -162,9 +162,9 @@ void WulforSettings::load(){
             settings.setValue(WB_CHAT_HIDE_SMILE_PANEL, static_cast<bool>(true));
             settings.setValue(WB_MAINWINDOW_MAXIMIZED,  static_cast<int>(true));
             settings.setValue(WB_MAINWINDOW_HIDE,       static_cast<int>(false));
-            settings.setValue(WB_MAINWINDOW_REMEMBER,   static_cast<int>(true));
+            settings.setValue(WB_MAINWINDOW_REMEMBER,   static_cast<int>(false));
             settings.setValue(WB_MAINWINDOW_USE_M_TABBAR, static_cast<int>(true));
-            settings.setValue(WB_MAINWINDOW_USE_SIDEBAR, static_cast<int>(false));
+            settings.setValue(WB_MAINWINDOW_USE_SIDEBAR, static_cast<int>(true));
             settings.setValue(WB_SEARCHFILTER_NOFREE,   static_cast<int>(false));
             settings.setValue(WB_SEARCH_DONTHIDEPANEL,  static_cast<int>(false));
             settings.setValue(WB_ANTISPAM_ENABLED,      static_cast<int>(false));
@@ -300,9 +300,9 @@ void WulforSettings::loadOldConfig(){
         intmap.insert(WB_CHAT_HIDE_SMILE_PANEL, static_cast<bool>(true));
         intmap.insert(WB_MAINWINDOW_MAXIMIZED,  static_cast<int>(true));
         intmap.insert(WB_MAINWINDOW_HIDE,       static_cast<int>(false));
-        intmap.insert(WB_MAINWINDOW_REMEMBER,   static_cast<int>(true));
+        intmap.insert(WB_MAINWINDOW_REMEMBER,   static_cast<int>(false));
         intmap.insert(WB_MAINWINDOW_USE_M_TABBAR, static_cast<int>(true));
-        intmap.insert(WB_MAINWINDOW_USE_SIDEBAR, static_cast<int>(false));
+        intmap.insert(WB_MAINWINDOW_USE_SIDEBAR, static_cast<int>(true));
         intmap.insert(WB_SEARCHFILTER_NOFREE,   static_cast<int>(false));
         intmap.insert(WB_SEARCH_DONTHIDEPANEL,  static_cast<int>(false));
         intmap.insert(WB_ANTISPAM_ENABLED,      static_cast<int>(false));
@@ -404,16 +404,20 @@ void WulforSettings::save(){
     //Do nothing
 }
 
-void WulforSettings::parseCmd(const QString &cmd){
+void WulforSettings::parseCmd(const QString &cmd, QString& res) {
     QStringList args = cmd.split(" ", QString::SkipEmptyParts);
 
-    if (args.size() != 2)
+    if (args.size() == 1) {
+        res = tr("Gui setting %1: %2").arg(args.at(0)).arg(getStr(args.at(0)));
+        return;
+    } else if (args.size() > 2)
         return;
 
     QString sname   = args.at(0);
     QString svalue  = args.at(1);
 
     setStr(sname, svalue);
+    res = tr("Change gui setting %1 to %2").arg(sname).arg(svalue);
 }
 
 void WulforSettings::loadTranslation(){
@@ -422,11 +426,11 @@ void WulforSettings::loadTranslation(){
     if (file.isEmpty() || !QFile::exists(file)){
         QString lc_prefix = QLocale::system().name();
 
-#ifndef WIN32
+#if !defined(Q_WS_WIN)
         file = QString(CLIENT_TRANSLATIONS_DIR) + QDir::separator();
 #else
         file = qApp->applicationDirPath()+QDir::separator()+QString(CLIENT_TRANSLATIONS_DIR)+QDir::separator();
-#endif//_WIN32
+#endif
         lc_prefix = lc_prefix.left(lc_prefix.indexOf("_"));
         file += lc_prefix + ".qm";
 
