@@ -273,10 +273,6 @@ QPixmap WulforUtil::FROMTHEME(const QString &name, bool resource){
         return QIcon(":/"+name+".png").pixmap(PXMTHEMESIDE, PXMTHEMESIDE);
     }
     else{
-//#if defined(Q_WS_X11)
-//        if (WBGET("app/use-icon-theme", false))
-//            return QIcon::fromTheme(name, loadPixmap(name+".png")).pixmap(PXMTHEMESIDE, PXMTHEMESIDE);
-//#endif
         return loadPixmap(name+".png");
     }
 }
@@ -285,10 +281,6 @@ QPixmap WulforUtil::FROMTHEME_SIDE(const QString &name, bool resource, const int
     if (resource)
         return QIcon(":/"+name+".png").pixmap(side, side);
     else{
-//#if defined(Q_WS_X11)
-//        if (WBGET("app/use-icon-theme", false))
-//            return QIcon::fromTheme(name, loadPixmap(name+".png")).pixmap(PXMTHEMESIDE, PXMTHEMESIDE);
-//#endif
         return loadPixmap(name+".png").scaled(side, side);
     }
 }
@@ -297,11 +289,11 @@ bool WulforUtil::loadIcons(){
     m_bError = false;
 
     QString icon_theme = WSGET(WS_APP_ICONTHEME);
-#ifndef WIN32
+#if !defined(Q_WS_WIN)
     QString fname = QString(CLIENT_RES_DIR)+QDir::separator()+icon_theme+".rcc";
 #else
     QString fname = qApp->applicationDirPath()+QDir::separator()+CLIENT_RES_DIR+QDir::separator()+icon_theme+".rcc";
-#endif//WIN32
+#endif
     bool resourceFound = false;
 
     if (QFile(fname).exists() && !WBGET("app/use-icon-theme", false))
@@ -367,7 +359,7 @@ bool WulforUtil::loadIcons(){
     m_PixmapMap[eiHUBMSG]       = FROMTHEME("hubmsg", resourceFound);
     m_PixmapMap[eiICON_APPL]    = FROMTHEME_SIDE("icon_appl_big", resourceFound, 128);
     m_PixmapMap[eiMESSAGE]      = FROMTHEME("message", resourceFound);
-    m_PixmapMap[eiMESSAGE_TRAY_ICON] = FROMTHEME("icon_msg", resourceFound);
+    m_PixmapMap[eiMESSAGE_TRAY_ICON] = FROMTHEME("icon_msg_big", resourceFound);
     m_PixmapMap[eiOWN_FILELIST] = FROMTHEME("own_filelist", resourceFound);
     m_PixmapMap[eiOPENLIST]     = FROMTHEME("openlist", resourceFound);
     m_PixmapMap[eiOPEN_LOG_FILE]= FROMTHEME("log_file", resourceFound);
@@ -682,7 +674,7 @@ QString WulforUtil::dcEnc2QtEnc(QString name){
     auto it = QtEnc2DCEnc.begin();
 
     for (; it != QtEnc2DCEnc.end(); ++it){
-        if (it.value() == name || it.value().indexOf(name) == 0)
+        if (it.value() == name || !it.value().indexOf(name))
             return it.key();
     }
 
@@ -881,11 +873,11 @@ QStringList WulforUtil::getLocalIfaces(){
     struct ifaddrs *ifap;
 
     if (getifaddrs(&ifap) == 0){
-        for (struct ifaddrs *i = ifap; i != NULL; i = i->ifa_next){
+        for (struct ifaddrs *i = ifap; i ; i = i->ifa_next){
             struct sockaddr *sa = i->ifa_addr;
 
             // If the interface is up, is not a loopback and it has an address
-            if ((i->ifa_flags & IFF_UP) && !(i->ifa_flags & IFF_LOOPBACK) && sa != NULL && !ifaces.contains(i->ifa_name))
+            if ((i->ifa_flags & IFF_UP) && !(i->ifa_flags & IFF_LOOPBACK) && sa && !ifaces.contains(i->ifa_name))
                 ifaces.push_back(i->ifa_name);
         }
 
@@ -903,11 +895,11 @@ QStringList WulforUtil::getLocalIPs(){
     struct ifaddrs *ifap;
 
     if (getifaddrs(&ifap) == 0){
-        for (struct ifaddrs *i = ifap; i != NULL; i = i->ifa_next){
+        for (struct ifaddrs *i = ifap; i ; i = i->ifa_next){
             struct sockaddr *sa = i->ifa_addr;
 
             // If the interface is up, is not a loopback and it has an address
-            if ((i->ifa_flags & IFF_UP) && !(i->ifa_flags & IFF_LOOPBACK) && sa != NULL){
+            if ((i->ifa_flags & IFF_UP) && !(i->ifa_flags & IFF_LOOPBACK) && sa){
                 void* src = NULL;
                 socklen_t len;
 
@@ -925,7 +917,7 @@ QStringList WulforUtil::getLocalIPs(){
                 }
 
                 // Convert the binary address to a string and add it to the output list
-                if (src != NULL){
+                if (src){
                     char address[len];
                     inet_ntop(sa->sa_family, src, address, len);
                     addresses.push_back(address);
@@ -1011,7 +1003,7 @@ int WulforUtil::sortOrderToInt(Qt::SortOrder order){
 }
 
 Qt::SortOrder WulforUtil::intToSortOrder(int i){
-    if (i == 0)
+    if (!i)
         return Qt::AscendingOrder;
     else
         return Qt::DescendingOrder;
