@@ -22,10 +22,6 @@ using namespace std;
 #include "dcpp/Thread.h"
 #include "dcpp/Singleton.h"
 
-#ifdef __HAIKU__
-#include "EiskaltApp_haiku.h"
-#endif
-
 #include "WulforUtil.h"
 #include "WulforSettings.h"
 #include "HubManager.h"
@@ -40,7 +36,11 @@ using namespace std;
 #include "MainWindow.h"
 #include "GlobalTimer.h"
 
-#ifndef __HAIKU__
+#if defined (__HAIKU__)
+#include "EiskaltApp_haiku.h"
+#elif defined(Q_WS_MAC)
+#include "EiskaltApp_mac.h"
+#else
 #include "EiskaltApp.h"
 #endif
 
@@ -69,10 +69,10 @@ void callBack(void* x, const std::string& a)
 
 void parseCmdLine(const QStringList &);
 
-#ifndef Q_WS_WIN
+#if !defined(Q_WS_WIN)
 #include <unistd.h>
 #include <signal.h>
-#ifndef __HAIKU__
+#if !defined (__HAIKU__)
 #include <execinfo.h>
 
 #ifdef ENABLE_STACKTRACE
@@ -91,6 +91,21 @@ void migrateConfig();
 #include <locale.h>
 #endif
 
+#if defined(Q_WS_MAC)
+#include <objc/objc.h>
+#include <objc/message.h>
+
+bool dockClickHandler(id self,SEL _cmd,...)
+{
+    Q_UNUSED(self)
+    Q_UNUSED(_cmd)
+    Notification *N = Notification::getInstance();
+    if (N)
+        N->slotShowHide();
+    return true;
+}
+#endif
+
 int main(int argc, char *argv[])
 {
     QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
@@ -104,7 +119,7 @@ int main(int argc, char *argv[])
     if (app.isRunning()){
         QStringList args = app.arguments();
         args.removeFirst();//remove path to executable
-#ifndef __HAIKU__
+#if !defined (__HAIKU__)
         app.sendMessage(args.join("\n"));
 #endif
         return 0;
@@ -137,6 +152,10 @@ int main(int argc, char *argv[])
     WulforSettings::getInstance()->loadTheme();
 
     WulforUtil::newInstance();
+#if defined(Q_WS_MAC)
+    // Disable system tray functionality in Mac OS X:
+    WBSET(WB_TRAY_ENABLED, false);
+#endif
 
     Text::hubDefaultCharset = WulforUtil::getInstance()->qtEnc2DcEnc(WSGET(WS_DEFAULT_LOCALE)).toStdString();
 
@@ -151,7 +170,11 @@ int main(int argc, char *argv[])
     ArenaWidgetManager::newInstance();
 
     MainWindow::newInstance();
+#if defined(Q_WS_MAC)
+    MainWindow::getInstance()->setUnload(false);
+#else // defined(Q_WS_MAC)
     MainWindow::getInstance()->setUnload(!WBGET(WB_TRAY_ENABLED));
+#endif // defined(Q_WS_MAC)
 
     app.connect(&app, SIGNAL(messageReceived(QString)), MainWindow::getInstance(), SLOT(parseInstanceLine(QString)));
 
@@ -175,14 +198,14 @@ int main(int argc, char *argv[])
     ScriptEngine::newInstance();
     QObject::connect(ScriptEngine::getInstance(), SIGNAL(scriptChanged(QString)), MainWindow::getInstance(), SLOT(slotJSFileChanged(QString)));
 #endif
-    
+
     ArenaWidgetFactory().create< dcpp::Singleton, FinishedUploads >();
     ArenaWidgetFactory().create< dcpp::Singleton, FinishedDownloads >();
     ArenaWidgetFactory().create< dcpp::Singleton, QueuedUsers >();
-    
+
     MainWindow::getInstance()->autoconnect();
     MainWindow::getInstance()->parseCmdLine(app.arguments());
-    
+
     if (!WBGET(WB_MAINWINDOW_HIDE) || !WBGET(WB_TRAY_ENABLED))
         MainWindow::getInstance()->show();
 
